==> chromium-59.0.3071.109.tar.xz: chromium-59.0.3071.109/chrome/browser/resources/settings/default_browser_page/default_browser_browser_proxy.js <==
// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

/**
 * @fileoverview A helper object used from the "Default Browser" section
 * to interact with the browser.
 */

/**
 * @typedef {{
 *   canBeDefault: boolean,
 *   isDefault: boolean,
 *   isDisabledByPolicy: boolean,
 *   isUnknownError: boolean,
 * }};
 */
var DefaultBrowserInfo;

cr.define('settings', function() {
  /** @interface */
  function DefaultBrowserBrowserProxy() {}

  DefaultBrowserBrowserProxy.prototype = {
    /**
     * Get the initial DefaultBrowserInfo and begin sending updates to
     * 'settings.updateDefaultBrowserState'.
     * @return {!Promise<DefaultBrowserInfo>}
     */
    requestDefaultBrowserState: function() {},

    /*
     * Try to set the current browser as the default browser. The new status of
     * the settings will be sent to 'settings.updateDefaultBrowserState'.
     */
    setAsDefaultBrowser: function() {},
  };

  /**
   * @constructor
   * @implements {settings.DefaultBrowserBrowserProxy}
   */
  function DefaultBrowserBrowserProxyImpl() {}
  cr.addSingletonGetter(DefaultBrowserBrowserProxyImpl);

  DefaultBrowserBrowserProxyImpl.prototype = {
    /** @override */
    requestDefaultBrowserState: function() {
      return cr.sendWithPromise(
          'SettingsDefaultBrowser.requestDefaultBrowserState');
    },

    /** @override */
    setAsDefaultBrowser: function() {
      chrome.send('SettingsDefaultBrowser.setAsDefaultBrowser');
    },
  };

  return {
    DefaultBrowserBrowserProxy: DefaultBrowserBrowserProxy,
    DefaultBrowserBrowserProxyImpl: DefaultBrowserBrowserProxyImpl,
  };
});

==> chromium_76.0.3809.71.orig.tar.xz: chromium-76.0.3809.71/chrome/browser/resources/settings/default_browser_page/default_browser_browser_proxy.js <==
// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

/**
 * @fileoverview A helper object used from the "Default Browser" section
 * to interact with the browser.
 */

/**
 * @typedef {{
 *   canBeDefault: boolean,
 *   isDefault: boolean,
 *   isDisabledByPolicy: boolean,
 *   isUnknownError: boolean,
 * }};
 */
let DefaultBrowserInfo;

cr.define('settings', function() {
  /** @interface */
  class DefaultBrowserBrowserProxy {
    /**
     * Get the initial DefaultBrowserInfo and begin sending updates to
     * 'settings.updateDefaultBrowserState'.
     * @return {!Promise<!DefaultBrowserInfo>}
     */
    requestDefaultBrowserState() {}

    /*
     * Try to set the current browser as the default browser. The new status of
     * the settings will be sent to 'settings.updateDefaultBrowserState'.
     */
    setAsDefaultBrowser() {}
  }

  /**
   * @implements {settings.DefaultBrowserBrowserProxy}
   */
  class DefaultBrowserBrowserProxyImpl {
    /** @override */
    requestDefaultBrowserState() {
      return cr.sendWithPromise('requestDefaultBrowserState');
    }

    /** @override */
    setAsDefaultBrowser() {
      chrome.send('setAsDefaultBrowser');
    }
  }

  cr.addSingletonGetter(DefaultBrowserBrowserProxyImpl);

  return {
    DefaultBrowserBrowserProxy: DefaultBrowserBrowserProxy,
    DefaultBrowserBrowserProxyImpl: DefaultBrowserBrowserProxyImpl,
  };
});
